==> apache-artemis-2.22.0-source-release.tar.gz: apache-artemis-2.22.0/artemis-core-client/src/main/java/org/apache/activemq/artemis/spi/core/remoting/ClientProtocolManagerFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.spi.core.remoting;

import org.apache.activemq.artemis.api.core.TransportConfiguration;
import org.apache.activemq.artemis.api.core.client.ServerLocator;

public interface ClientProtocolManagerFactory {

   ClientProtocolManager newProtocolManager();

   ClientProtocolManagerFactory setLocator(ServerLocator locator);

   ServerLocator getLocator();

   /**
    * Adapt the transport configuration passed in parameter and return an adapted one that is suitable to use with ClientProtocolManager
    * created by this factory.
    *
    * @param tc the original TransportConfiguration
    * @return the adapted TransportConfiguration
    */
   TransportConfiguration adaptTransportConfiguration(TransportConfiguration tc);
}

==> apache-artemis-2.42.0-source-release.tar.gz: apache-artemis-2.42.0/artemis-core-client/src/main/java/org/apache/activemq/artemis/spi/core/remoting/ClientProtocolManagerFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.spi.core.remoting;

import org.apache.activemq.artemis.api.core.TransportConfiguration;
import org.apache.activemq.artemis.api.core.client.ServerLocator;

public interface ClientProtocolManagerFactory {

   ClientProtocolManager newProtocolManager();

   ClientProtocolManagerFactory setLocator(ServerLocator locator);

   ServerLocator getLocator();

   /**
    * Adapt the transport configuration passed in parameter and return an adapted one that is suitable to use with
    * ClientProtocolManager created by this factory.
    *
    * @param tc the original TransportConfiguration
    * @return the adapted TransportConfiguration
    */
   TransportConfiguration adaptTransportConfiguration(TransportConfiguration tc);
}
